#!/usr/bin/env bash
set -e

if [ -f /etc/photon-release ]; then
    source /config/docker_install.conf
    : "${ClusterMembership:?Error could not find ClusterMembership in docker_install.conf.}"
fi

if [[ -f "/usr/share/zoneinfo/${TZ}" ]]; then
    ln -snf "/usr/share/zoneinfo/${TZ}" /etc/localtime
    echo "${TZ}" > /etc/timezone
fi

sigterm_handler() {
    if [ -f /etc/photon-release ]; then
        if [ ! "${ClusterMembership}" == "Minion" ]; then
            /root/scripts/startup.sh stop
        fi
        test -f /var/run/sshd.pid && kill "$(cat /var/run/sshd.pid)"
    else
        service "cb-enterprise" stop
        service sshd stop
    fi
    exit
}

trap sigterm_handler SIGINT SIGTERM

main() {
    if [ -f /etc/photon-release ]; then
        # Sleep for half a second so docker logs has a chance to attach in
        # the event there are any errors during the startup
        sleep 0.5

        /root/scripts/create_folders.sh
        /root/scripts/install_sensors.sh

        # permissions fixes for the /config folder
        # normally edr perm fixes happen in file_permissions.sh but the /config folder
        # only exists in dockerized photon installs
        chown root:cb /config/nginx
        chmod 755 /config/nginx

        if [ "${ClusterMembership}" == "Standalone" ]; then
            /root/scripts/startup.sh start || true
        elif [ "${ClusterMembership}" == "Primary" ]; then
            /usr/share/cb/cbcluster start || true
        else
            if [ ! -f "/config/cb.conf" ]; then
                sed -i 's,PasswordAuthentication no,PasswordAuthentication yes,g' /etc/ssh/sshd_config
                sed -i 's,KbdInteractiveAuthentication no,KbdInteractiveAuthentication yes,g' /etc/ssh/sshd_config

                # Generate random password
                local password
                password=$(tr -dc A-Za-z0-9 < /dev/urandom | head -c 13)
                echo "root:$password" | chpasswd
                echo "Please use credentials username: root, password: $password to add this node to the cluster."
            fi

            /usr/sbin/sshd
        fi
    else
        /root/scripts/create_folders.sh

        service sshd start
        service "cb-enterprise" start
    fi

    if [ "${ClusterMembership}" != "Minion" ]; then
        server_type="EDR Server"
        echo "VMware Carbon Black $server_type Started."
    else
        echo "The minion container is now running, please control the cluster from the primary node."
    fi

    # sleep forever
    while true; do sleep 1; done
}

main "$@"
