#!/usr/bin/env bash
set -e

readonly DOCKER_INSTALL_FILE=/config/docker_install.conf

ask() {
    local choice1=${2:-yes}
    local choice2=${3:-no}
    local char1=${choice1:0:1}
    local char2=${choice2:0:1}

    while true; do
        local response
        read -r -p "${1} [${char1,}/${char2,}]: " response
        case ${response,,} in
            "${char1,}" | "${choice1,,}")
                echo "${choice1}"
                break
                ;;
            "${char2,}" | "${choice2,,}")
                echo "${choice2}"
                break
                ;;
        esac
    done
}

get_node_type() {
    if [ -n "$EDR_NODE_TYPE" ]; then
        node_type="$EDR_NODE_TYPE"
        return
    fi

    trap 'exit 1' SIGINT

    echo "To initialize this EDR system we need to know what type of server it will be."
    if [ "$(ask "Is this system intended to be a minion in a cluster?")" == "yes" ]; then
        node_type="Minion"
    else
        node_type="Standalone"
    fi
    trap - SIGINT
}

extract_license_rpm() {
    cd /root/license
    rpm2cpio ./carbon-black-release.x86_64.rpm | cpio -idm
    cp -a /root/license/etc/cb/certs /config/
    cp -a /root/license/etc/cb/server.lic /config/server.lic
    cd - > /dev/null
}

main() {
    local host_uid=${1:-0}

    /root/scripts/create_folders.sh

    get_node_type
    extract_license_rpm
    if [ $node_type != "Minion" ]; then
        local args=()
        if [ -f /root/cbinit.conf ]; then
            args+=(/root/cbinit.conf)
        fi
        /usr/share/cb/cbinit "${args[@]}"
    fi

    mkdir -p /sensors/rpms
    chown "${host_uid}" /sensors/rpms
    mkdir -p /sensors/installers
    cp -fa /usr/share/cb/setup/sensor-installers/* /sensors/installers

    cp -a /root/config.template/* /config

    if [ $node_type == "Minion" ]; then
        ssh-keygen -A
        mv --backup=existing /etc/ssh/ssh_host_*_key* /config/sshd/
    fi

    echo "ClusterMembership=${node_type}" > ${DOCKER_INSTALL_FILE}
    echo "HostName=${EDR_HOST_HOSTNAME}" >> ${DOCKER_INSTALL_FILE}
    chown 8300:8300 ${DOCKER_INSTALL_FILE}
    chmod a+r ${DOCKER_INSTALL_FILE}

    echo "EDR initialization complete."
}

main "$@"
