#!/usr/bin/env bash
set -e

if [ "$1" == "wrapper" ]; then
    cat /root/scripts/edr-docker
    exit
fi

if [[ -f /etc/photon-release && -z "${ClusterMembership}" && -z "${_CB_CBR_COMPOSE_ENVIRONMENT}" ]]; then
    echo "Error: Don't run this image directly using \`docker run\`, please use the edr-docker wrapper script instead."
    echo ""
    echo "To extract the wrapper script run the following command:"
    echo "docker run --rm projects.registry.vmware.com/carbonblack/edr-server:current wrapper > edr-docker && chmod +x edr-docker"
    echo "Please refer to the documentation for detailed instructions on usage."
    exit
fi

if [ -n "$_CB_ENABLE_CODE_COVERAGE_RECORDING" ]; then
    touch /usr/share/cb/.enable_code_coverage_recording
else
    rm -f /usr/share/cb/.enable_code_coverage_recording
fi

# Set CBIO hostname because docker resets /etc/hosts on startup
CBIO=${CBIO:-False}
if [ "${CBIO}" = "True" ]; then
    hostname=$(uname -n)
    if ! ping -q -W 5 -c 1 "sensors.$hostname" > /dev/null 2>&1; then
        if ! grep -q "sensors.$hostname" /etc/hosts; then
            echo >> /etc/hosts
            echo "127.0.0.1    sensors.$hostname" >> /etc/hosts
        fi
    fi
fi

if [ -f /etc/photon-release ]; then
    INITIALIZED_FILE=/config/docker_install.conf
else
    INITIALIZED_FILE=/etc/cb/.initialized
fi

if [[ ! -f ${INITIALIZED_FILE} ]]; then
    if [ ! -f /etc/photon-release ]; then
        # Copy the cb conf & data directories back and set correct permissions so they get populated
        # and have the correct permissions if we're using external volume mounts.
        mkdir -p /etc/cb
        chown cb:cb /etc/cb
        cp -rp /root/etc.cb.template/* /etc/cb

        mkdir -p /var/cb
        chown cb:cb /var/cb
        cp -rp /root/var.cb.template/* /var/cb

        /root/scripts/create_folders.sh
    fi

    # We need to update the server in Postgres first so that
    # coreservices will see the correct name when it starts up for the first time
    IPADDRESS="$(ifconfig | grep -E "(Bcast|broadcast)" | awk '{print $2}' | sed 's/addr://g')"
    echo -e "\ndefault_sensor_server_url=https://${IPADDRESS}:443" >> /root/cbinit.conf

    if [ -f /etc/photon-release ]; then
        rsyslogd
    else
        service rsyslog start
    fi

    if [ -f /etc/photon-release ]; then
        export EDR_NODE_TYPE=Standalone
        /root/scripts/edr_init.sh
    else
        "/usr/share/cb/cbinit" /root/cbinit.conf
    fi

    if [ -f /etc/photon-release ]; then
        kill "$(cat /var/run/rsyslogd.pid)"
    else
        service rsyslog stop
    fi

    sed -i s/SmallDeploymentMode=False/SmallDeploymentMode=true/g /etc/cb/cb.conf
    sed -i s/AllianceVerifyServerCert=1/AllianceVerifyServerCert=0/g /etc/cb/cb.conf

    # FUTURE: As we proceed in versions, evaluate the needs for any of these going forward
    # shellcheck disable=SC2129
    echo -e "\n\n#------------------------------------------------------------------------------" >> /etc/cb/cb.conf
    echo -e "# Other Settings --------------------------------------------------------------" >> /etc/cb/cb.conf
    echo -e "#------------------------------------------------------------------------------" >> /etc/cb/cb.conf
    echo -e "EventStoreCacheTtl=1" >> /etc/cb/cb.conf
    echo -e "ExposeEventPurgeAPI=true" >> /etc/cb/cb.conf
    echo -e "EnableExtendedApiAuditLogging=true" >> /etc/cb/cb.conf
    echo -e "CbSwaggerEnabled=true" >> /etc/cb/cb.conf
    echo -e "AllianceSettingsTTLMaxSec=0" >> /etc/cb/cb.conf
    echo -e "TicEnableMd5Lookups=true" >> /etc/cb/cb.conf
    echo -e "\n" >> /etc/cb/cb.conf

    # Hook for required settings for automation
    if [[ -f /root/required-cb.conf ]]; then
        cat /root/required-cb.conf >> /etc/cb/cb.conf
    fi

    if [ ! -f /etc/photon-release ]; then
        touch ${INITIALIZED_FILE}
    fi
fi

exec "$@"
